==> kdepimlibs-4.8.5.tar.xz: kdepimlibs-4.8.5/akonadi/contact/editor/imeditwidget.h <==
/*
    This file is part of Akonadi Contact.

    Copyright (c) 2009 Tobias Koenig <tokoe@kde.org>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
*/

#ifndef IMEDITWIDGET_H
#define IMEDITWIDGET_H

#include <QtGui/QWidget>

#include <kabc/addressee.h>

#include "im/immodel.h"

class KLineEdit;
class QToolButton;

/**
 * This widget displays an input field for changing
 * the instant messaging id of a contact.
 */
class IMEditWidget : public QWidget
{
  Q_OBJECT

  public:
    IMEditWidget( QWidget *parent = 0 );
    ~IMEditWidget();

    void loadContact( const KABC::Addressee &contact );
    void storeContact( KABC::Addressee &contact ) const;

    void setReadOnly( bool readOnly );

  private Q_SLOTS:
    void edit();

  private:
    KLineEdit *mIMEdit;
    QToolButton *mEditButton;
    IMAddress::List mIMAddresses;
};

#endif

==> kdepimlibs_4.13.3.orig.tar.xz: kdepimlibs-4.13.3/akonadi/contact/editor/imeditwidget.h <==
/*
    This file is part of Akonadi Contact.

    Copyright (c) 2009 Tobias Koenig <tokoe@kde.org>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
*/

#ifndef IMEDITWIDGET_H
#define IMEDITWIDGET_H

#include <QWidget>

#include <kabc/addressee.h>

#include "im/immodel.h"

class KLineEdit;
class QToolButton;

/**
 * This widget displays an input field for changing
 * the instant messaging id of a contact.
 */
class IMEditWidget : public QWidget
{
  Q_OBJECT

  public:
    explicit IMEditWidget( QWidget *parent = 0 );
    ~IMEditWidget();

    void loadContact( const KABC::Addressee &contact );
    void storeContact( KABC::Addressee &contact ) const;

    void setReadOnly( bool readOnly );

  private Q_SLOTS:
    void edit();

  private:
    KLineEdit *mIMEdit;
    QToolButton *mEditButton;
    IMAddress::List mIMAddresses;
};

#endif
